@@ -208,7 +208,7 @@ class MultiTest(object):
         """
         
         Fs = np.sum( -2 * np.log( np.maximum(self._pvals, MIN_PVAL) ) )
-        Fs_pval = chi2.sf(Fs, df = len(self._pvals))
+        Fs_pval = chi2.sf(Fs, df = 2*len(self._pvals))
         # we average instead of taking sum, so that under 
         # the null Fs * n_pvals has a chisquared distribution with
         # number of df equals n_pvals
